#
# This is the SPEC file for creating binary and source RPMs for the Qubes DB.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2013  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

Name:		qubes-db
Version:	4.2.5
Release:	1%{?dist}
Summary:	QubesDB tools

Group:		Qubes
License:	GPL
URL:		http://www.qubes-os.org/

BuildRequires:	gcc
BuildRequires:	qubes-libvchan-devel
BuildRequires:	systemd-devel
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
Source0:    %{name}-%{version}.tar.gz

%description
QubesDB management tools and daemon.

%package libs
Summary:	QubesDB libs
Group:		Qubes

%description libs
QubesDB client library.

%package devel
Summary:	QubesDB client header files
Group:		Qubes
Requires:	qubes-db-libs

%description devel
Header files for QubesDB client library and daemon protocol.

%package -n python%{python3_pkgversion}-qubesdb
Summary:    Python%{python3_pkgversion} bindings for QubesDB
Requires:   qubes-db-libs
%{?python_provide:%python_provide python%{python3_pkgversion}-qubesdb}

%description -n python%{python3_pkgversion}-qubesdb
Python3 bindings for QubesDB

%prep
%setup -q 

%build
%{?set_build_flags}
make %{?_smp_mflags} PYTHON=%{__python3} all

%install
make install \
         PYTHON=%{__python3} \
         DESTDIR=%{buildroot} \
         LIBDIR=%{_libdir} \
         BINDIR=%{_bindir} \
         SBINDIR=%{_sbindir}

%files
%doc
%{_bindir}/qubesdb-cmd
%{_bindir}/qubesdb-read
%{_bindir}/qubesdb-read-bool
%{_bindir}/qubesdb-write
%{_bindir}/qubesdb-rm
%{_bindir}/qubesdb-multiread
%{_bindir}/qubesdb-list
%{_bindir}/qubesdb-watch
%{_sbindir}/qubesdb-daemon

%files libs
%{_libdir}/libqubesdb.so

%files -n python%{python3_pkgversion}-qubesdb
%{python3_sitearch}/QubesDB-*egg-info
%{python3_sitearch}/qubesdb.*.so

%files devel
/usr/include/qubesdb.h
/usr/include/qubesdb-client.h

%changelog
* Sun Apr 28 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qubesdb

* Sun Apr 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2fbe383
- version 4.2.5

* Sun Apr 28 2024 Ludovic Bellier <lbellier-gth@zyrianes.net> - 35c1657
- Update archlinux python version dependency to <3.13

* Sun Nov 05 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fafd83e
- rpm: adjust systemd dependency

* Thu May 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a99f9d5
- version 4.2.4

* Wed May 03 2023 Ludovic Bellier <lbellier-gth@zyrianes.net> - ed937c4
- Update archlinux python version dependency to <3.12

* Wed Apr 26 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 43db33f
- version 4.2.3

* Wed Apr 26 2023 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6935ca7
- archlinux: add python-setuptools in depends

* Sun Apr 16 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a490442
- version 4.2.2

* Sun Apr 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 5ca46cd
- Support providing a default value to qubesdb-read

* Sat Apr 01 2023 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 172d738
- Rework archlinux packaging

* Sat Mar 18 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 02a6590
- python: migrate away from deprecated distutils

* Thu Mar 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 8c0cc77
- Stop testing on R4.1

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aca66da
- version 4.2.1

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 512566a
- rpm,debian: remove explicit dependency on vchan

* Thu Dec 29 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 56e446a
- version 4.2.0

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a202584
- Add write permission to qubesdb-daemon on var_run_t

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - e825d37
- Avoid explicit mkdir

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7aea4b8
- Simplify SELinux policy

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 924383f
- SELinux policies require qubes-core-agent-selinux

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b959baf
- Simplify daemon startup and fix UB

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 80a3cc8
- Try to get qubesdb working with SELinux enforcing

* Wed Dec 21 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a395852
- Implement SELinux policy for QubesDB

* Sat Dec 17 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a8cab70
- Do not use select(2)

* Sat Dec 17 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1aba6b5
- version 4.1.15

* Sat Dec 17 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1c5c88a
- Fix some Doxygen comments

* Fri Dec 16 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 329c59d
- debian: remove remaining python2 dep

* Sun Oct 16 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 9743538
- Fix qubesdb-read-bool on missing keys

* Tue Oct 11 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 37c8c27
- version 4.1.14

* Mon May 09 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9f65b84
- .qubesbuilder: replace 'spec' by 'build'

* Mon Apr 25 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - d327cb8
- Add Qubes Builder v2 integration

* Fri Apr 15 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 0c4a7c4
- Drop Travis CI

* Sat Apr 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e94f2c9
- Fix mingw build

* Mon Mar 21 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 13801fe
- ci: build on windows too

* Tue Mar 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 5399147
- Fix OSS Fuzz integration

* Sat Mar 05 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4831306
- version 4.1.13

* Sat Mar 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b9870c9
- CLI tools: distinguish "no such entry" and "error"

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 892cde0
- Reserve ENOENT for "no such path in QubesDB"

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 55fd470
- Write error messages if fflush() fails

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 484f173
- Better error checking when writing to stdout

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - e6c1516
- Daemon: Zeroize memory before freeing it

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 00ad65e
- Securely zero buffer memory before freeing it

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 31038b5
- Fix an unchecked malloc

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - f3db5c1
- Move newline printing to common code

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1ddb48c
- Forbid leading dashes in qubesdb entry names

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ec06222
- Add documentation for -h

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 32a28ea
- Fix error checking and a memory leak

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 203725e
- Exit non-zero on I/O errors

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ca0dc1f
- Allow removing a value after reading it

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7e9c0b7
- Add a comma after enum variant

* Thu Mar 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 015adec
- Fix build with -Werror=missing-prototypes

